@@ -1,3 +1,4 @@
+#include <QApplication>
 #include <QDir>
 #include <QFileInfo>
 #include <QDateTime>
@@ -23,7 +24,6 @@ namespace {
 
 const char *kFileCacheTopDirName = "file-cache";
 const char *kFileCacheTempTopDirName = "file-cache-tmp";
-const char *kFileCacheDBFileName = "file-cache.db";
 
 inline bool addPath(QFileSystemWatcher *watcher, const QString &file) {
   if (watcher->files().contains(file))
@@ -51,8 +51,16 @@ SINGLETON_IMPL(AutoUpdateManager)
 
 AutoUpdateManager::AutoUpdateManager()
 {
+    system_shut_down_ = false;
     connect(&watcher_, SIGNAL(fileChanged(const QString&)),
             this, SLOT(onFileChanged(const QString&)));
+    connect(qApp, SIGNAL(aboutToQuit()),
+            this, SLOT(systemShutDown()));
+}
+
+void AutoUpdateManager::systemShutDown()
+{
+    system_shut_down_ = true;
 }
 
 void AutoUpdateManager::start()
@@ -80,7 +88,14 @@ void AutoUpdateManager::watchCachedFile(const Account& account,
     }
 
     addPath(&watcher_, local_path);
-    watch_infos_[local_path] = WatchedFileInfo(account, repo_id, path);
+
+    QFileInfo finfo(local_path);
+    watch_infos_[local_path] =
+        WatchedFileInfo(account,
+                        repo_id,
+                        path,
+                        finfo.lastModified().toMSecsSinceEpoch(),
+                        finfo.size());
 }
 
 void AutoUpdateManager::cleanCachedFile()
@@ -103,21 +118,24 @@ void AutoUpdateManager::cleanCachedFile()
 void AutoUpdateManager::onFileChanged(const QString& local_path)
 {
     qDebug("[AutoUpdateManager] detected cache file %s changed", local_path.toUtf8().data());
-#ifdef Q_OS_MAC
-    if (MacImageFilesWorkAround::instance()->isRecentOpenedImage(local_path)) {
-        return;
-    }
-#endif
-    removePath(&watcher_, local_path);
-    QString repo_id, path_in_repo;
     if (!watch_infos_.contains(local_path)) {
         // filter unwanted events
         return;
     }
 
     WatchedFileInfo &info = watch_infos_[local_path];
+    QFileInfo finfo(local_path);
 
-    if (!QFileInfo(local_path).exists()) {
+#ifdef Q_OS_MAC
+    if (MacImageFilesWorkAround::instance()->isRecentOpenedImage(local_path)) {
+        qDebug("[AutoUpdateManager] skip the image file updates on mac for %s", toCStr(local_path));
+        return;
+    }
+#endif
+    removePath(&watcher_, local_path);
+    QString repo_id, path_in_repo;
+
+    if (!finfo.exists()) {
         qDebug("[AutoUpdateManager] detected cache file %s renamed or removed", local_path.toUtf8().data());
         WatchedFileInfo deferred_info = info;
         removeWatch(local_path);
@@ -129,8 +147,7 @@ void AutoUpdateManager::onFileChanged(const QString& local_path)
         return;
     }
 
-    DataManager data_mgr(info.account);
-    FileNetworkTask *task = data_mgr.createUploadTask(
+    FileNetworkTask *task = seafApplet->dataManager()->createUploadTask(
         info.repo_id, ::getParentPath(info.path_in_repo),
         local_path, ::getBaseName(local_path), true);
 
@@ -145,27 +162,50 @@ void AutoUpdateManager::onFileChanged(const QString& local_path)
 
 void AutoUpdateManager::onUpdateTaskFinished(bool success)
 {
+    if (system_shut_down_) {
+        return;
+    }
+
     FileUploadTask *task = qobject_cast<FileUploadTask *>(sender());
     if (task == NULL)
         return;
     const QString local_path = task->localFilePath();
+    const QFileInfo finfo = QFileInfo(local_path);
+    if (!finfo.exists()) {
+        //TODO: What if the delete&recreate happens just before this function is called?
+        qWarning("[AutoUpdateManager] file %s not exists anymore", toCStr(local_path));
+        return;
+    }
+
+    if (!watch_infos_.contains(local_path)) {
+        qWarning("[AutoUpdateManager] no watch info for file %s", toCStr(local_path));
+        return;
+    }
+    WatchedFileInfo& info = watch_infos_[local_path];
+
     if (success) {
         qDebug("[AutoUpdateManager] uploaded new version of file %s", local_path.toUtf8().data());
         seafApplet->trayIcon()->showMessage(tr("Upload Success"),
-                                            tr("File \"%1\"\nuploaded successfully.").arg(QFileInfo(local_path).fileName()),
+                                            tr("File \"%1\"\nuploaded successfully.").arg(finfo.fileName()),
                                             task->repoId());
+
+        FileCache::instance()->saveCachedFileId(task->repoId(),
+                                                info.path_in_repo,
+                                                task->account().getSignature(),
+                                                task->oid(),
+                                                task->localFilePath());
         emit fileUpdated(task->repoId(), task->path());
-        addPath(&watcher_, local_path);
-        WatchedFileInfo& info = watch_infos_[local_path];
-        info.uploading = false;
     } else {
-        qWarning("[AutoUpdateManager] failed to upload new version of file %s", local_path.toUtf8().data());
+        qWarning("[AutoUpdateManager] failed to upload new version of file %s: %s",
+                 toCStr(local_path),
+                 toCStr(task->errorString()));
         seafApplet->trayIcon()->showMessage(tr("Upload Failure"),
                                             tr("File \"%1\"\nfailed to upload.").arg(QFileInfo(local_path).fileName()),
                                             task->repoId());
-        watch_infos_.remove(local_path);
-        return;
     }
+
+    addPath(&watcher_, local_path);
+    info.uploading = false;
 }
 
 void AutoUpdateManager::removeWatch(const QString& local_path)
@@ -229,15 +269,8 @@ void CachedFilesCleaner::run()
                                kFileCacheTopDirName);
     QString file_cache_tmp_dir = pathJoin(seafApplet->configurator()->seafileDir(),
                                    kFileCacheTempTopDirName);
-    QString file_cache_db_file = pathJoin(seafApplet->configurator()->seafileDir(),
-                                   kFileCacheDBFileName);
 
     qDebug("[AutoUpdateManager] removing cached files");
-    if (QFile(file_cache_db_file).exists()) {
-        if (!QFile(file_cache_db_file).remove()) {
-            qWarning("[AutoUpdateManager] failed to remove db file");
-        }
-    }
     if (QDir(file_cache_tmp_dir).exists()) {
         delete_dir_recursively(file_cache_tmp_dir);
     }
