@@ -5,10 +5,12 @@
 #include <QHash>
 #include <QQueue>
 #include <QRunnable>
+#include <QScopedPointer>
 
 #include "utils/singleton.h"
 #include "account.h"
 #include "data-cache.h"
+#include "data-mgr.h"
 
 class AutoUpdateManager : public QObject {
     SINGLETON_DEFINE(AutoUpdateManager)
@@ -29,6 +31,7 @@ private slots:
     void onFileChanged(const QString& path);
     void onUpdateTaskFinished(bool success);
     void checkFileRecreated();
+    void systemShutDown();
 
 private:
     AutoUpdateManager();
@@ -39,21 +42,30 @@ private:
         Account account;
         QString repo_id;
         QString path_in_repo;
+        qint64 mtime;
+        qint64 fsize;
+
         bool uploading;
 
         WatchedFileInfo() : uploading(false) {}
         WatchedFileInfo(const Account& account,
                         const QString& repo_id,
-                        const QString& path_in_repo)
+                        const QString& path_in_repo,
+                        qint64 mtime,
+                        qint64 fsize)
             : account(account),
               repo_id(repo_id),
               path_in_repo(path_in_repo),
+              mtime(mtime),
+              fsize(fsize),
               uploading(false) {}
     };
 
     QHash<QString, WatchedFileInfo> watch_infos_;
 
     QQueue<WatchedFileInfo> deleted_files_infos_;
+
+    bool system_shut_down_;
 };
 
 #ifdef Q_OS_MAC
