@@ -13,6 +13,7 @@
 #include "auto-update-mgr.h"
 #include "api/requests.h"
 #include "repo-service.h"
+#include "account-mgr.h"
 
 #include "filebrowser/file-browser-requests.h"
 #include "filebrowser/tasks.h"
@@ -31,9 +32,10 @@ const int kPasswordCacheExpirationMSecs = 30 * 60 * 1000;
  * Cache loaded dirents. But default cache expires after 1 minute.
  */
 
-DataManager::DataManager(const Account &account)
-    : account_(account),
-      filecache_(FileCache::instance()),
+SINGLETON_IMPL(DataManager)
+
+DataManager::DataManager()
+    : filecache_(FileCache::instance()),
       dirents_cache_(DirentsCache::instance())
 {
 }
@@ -47,6 +49,14 @@ DataManager::~DataManager()
     }
 }
 
+void DataManager::start()
+{
+    account_ = seafApplet->accountManager()->currentAccount();
+
+    connect(seafApplet->accountManager(), SIGNAL(accountsChanged()),
+            this, SLOT(onAccountChanged()));
+}
+
 bool DataManager::getDirents(const QString& repo_id,
                              const QString& path,
                              QList<SeafDirent> *dirents,
@@ -298,12 +308,42 @@ QString DataManager::getLocalCachedFile(const QString& repo_id,
                                         const QString& file_id)
 {
     QString local_file_path = getLocalCacheFilePath(repo_id, fpath);
-    if (!QFileInfo(local_file_path).exists()) {
+    QFileInfo finfo(local_file_path);
+    if (!finfo.exists()) {
+        qDebug ("No cache file for %s\n", toCStr(fpath));
         return "";
     }
 
-    QString cached_file_id = filecache_->getCachedFileId(repo_id, fpath);
-    return cached_file_id == file_id ? local_file_path : "";
+    FileCache::CacheEntry entry;
+    if (!filecache_->getCacheEntry(repo_id, fpath, &entry)) {
+        qDebug ("No cache db entry for %s\n", toCStr(fpath));
+        return "";
+    }
+
+    if (entry.file_id == file_id) {
+        qDebug ("cache file id matched for %s\n", toCStr(fpath));
+        return local_file_path;
+    } else {
+        // The file is updated on server
+        qint64 mtime = finfo.lastModified().toMSecsSinceEpoch();
+        bool use_cached = false;
+        if (mtime != entry.seafile_mtime) {
+            qDebug ("cache file is updated locally (mtime changed), use it: %s\n", toCStr(fpath));
+            use_cached = true;
+        } else if (finfo.size() != entry.seafile_size) {
+            qDebug ("cache file is updated locally (size changed), use it: %s\n", toCStr(fpath));
+            use_cached = true;
+        }
+
+        if (use_cached) {
+            // If the file is also updated locally, open it directly
+            return local_file_path;
+        } else {
+            qDebug ("cache file is outdated, download newer version: %s\n", toCStr(fpath));
+            // Otherwise the newer version would be downloaded
+            return "";
+        }
+    }
 }
 
 FileDownloadTask* DataManager::createDownloadTask(const QString& repo_id,
@@ -338,11 +378,11 @@ void DataManager::onFileDownloadFinished(bool success)
     if (success) {
         filecache_->saveCachedFileId(task->repoId(),
                                      task->path(),
+                                     account_.getSignature(),
                                      task->fileId(),
-                                     account_.getSignature());
+                                     task->localFilePath());
         // TODO we don't want to watch readonly files
-        AutoUpdateManager::instance()->watchCachedFile(
-            account_, task->repoId(), task->path());
+        AutoUpdateManager::instance()->watchCachedFile(account_, task->repoId(), task->path());
     }
 }
 
@@ -487,3 +527,8 @@ void DataManager::onCreateSubrepoRefreshSuccess(const ServerRepo& repo)
     // it is not expected
     emit createSubrepoFailed(ApiError::fromHttpError(500));
 }
+
+void DataManager::onAccountChanged()
+{
+    account_ = seafApplet->accountManager()->currentAccount();
+}
