@@ -89,7 +89,7 @@ FileBrowserDialog::FileBrowserDialog(const Account &account, const ServerRepo& r
 {
     current_lpath_ = current_path_.split('/');
 
-    data_mgr_ = new DataManager(account_);
+    data_mgr_ = seafApplet->dataManager();
 
     // In German translation there is a "seafile" string, so need to use tr("..").arg(..) here
     QString title = tr("Cloud File Browser");
@@ -234,7 +234,6 @@ FileBrowserDialog::FileBrowserDialog(const Account &account, const ServerRepo& r
 
 FileBrowserDialog::~FileBrowserDialog()
 {
-    delete data_mgr_;
 }
 
 void FileBrowserDialog::init()
@@ -396,6 +395,11 @@ void FileBrowserDialog::fetchDirents()
     fetchDirents(false);
 }
 
+void FileBrowserDialog::updateFileCount()
+{
+    details_label_->setText(tr("%1 items").arg(table_model_->rowCount()));
+}
+
 void FileBrowserDialog::fetchDirents(bool force_refresh)
 {
     if (repo_.encrypted && !data_mgr_->isRepoPasswordSet(repo_.id)) {
@@ -556,6 +560,7 @@ void FileBrowserDialog::onDirClicked(const SeafDirent& dir)
 
 void FileBrowserDialog::enterPath(const QString& path)
 {
+    // printf ("enter path %s\n", toCStr(path));
     current_path_ = path;
     // use QUrl::toPercentEncoding if need
     fetchDirents();
@@ -775,6 +780,7 @@ void FileBrowserDialog::uploadOrUpdateMutipleFile(const QStringList &paths)
 void FileBrowserDialog::onDownloadFinished(bool success)
 {
     FileDownloadTask *task = qobject_cast<FileDownloadTask *>(sender());
+    QString _error;
     if (task == NULL)
         return;
     if (success) {
@@ -788,8 +794,13 @@ void FileBrowserDialog::onDownloadFinished(bool success)
 
         if (task->error() == FileNetworkTask::TaskCanceled)
             return;
-
-        QString msg = tr("Failed to download file: %1").arg(task->errorString());
+  
+        if(task->httpErrorCode() == 404) {
+             _error = tr("File does not exit");
+        } else {
+             _error = task->errorString();
+        }
+        QString msg = tr("Failed to download file: %1").arg(_error);
         seafApplet->warningBox(msg, this);
     }
 }
@@ -826,6 +837,7 @@ void FileBrowserDialog::onUploadFinished(bool success)
         const SeafDirent dir = SeafDirent::dir(task->name());
         // TODO: insert the Item prior to the item where uploading occurs
         table_model_->insertItem(0, dir);
+        updateFileCount();
         return;
     }
 
@@ -858,6 +870,7 @@ void FileBrowserDialog::onUploadFinished(bool success)
         else
             table_model_->replaceItem(name, dirent);
     }
+    updateFileCount();
 }
 
 bool FileBrowserDialog::setPasswordAndRetry(FileNetworkTask *task)
@@ -934,6 +947,7 @@ void FileBrowserDialog::updateTable(const QList<SeafDirent>& dirents)
         upload_button_->setEnabled(true);
     }
     gohome_action_->setEnabled(current_path_ != "/");
+    updateFileCount();
 }
 
 void FileBrowserDialog::chooseFileToUpload()
@@ -1049,6 +1063,7 @@ void FileBrowserDialog::onDirectoryCreateSuccess(const QString &path)
     const SeafDirent dirent = SeafDirent::dir(name);
     // TODO insert to the pos where the drop event triggered
     table_model_->insertItem(0, dirent);
+    updateFileCount();
 }
 
 void FileBrowserDialog::onDirectoryCreateFailed(const ApiError&error)
@@ -1115,6 +1130,7 @@ void FileBrowserDialog::onDirentRemoveSuccess(const QString& path)
     if (::pathJoin(current_path_, name) != path)
         return;
     table_model_->removeItemNamed(name);
+    updateFileCount();
 }
 
 void FileBrowserDialog::onDirentRemoveFailed(const ApiError&error)
@@ -1132,6 +1148,7 @@ void FileBrowserDialog::onDirentsRemoveSuccess(const QString& parent_path,
         // printf("removed file: %s\n", name.toUtf8().data());
         table_model_->removeItemNamed(name);
     }
+    updateFileCount();
 }
 
 void FileBrowserDialog::onDirentsRemoveFailed(const ApiError&error)
