@@ -30,6 +30,7 @@
 #include "api/api-error.h"
 #include "api/requests.h"
 #include "filebrowser/auto-update-mgr.h"
+#include "repo-service.h"
 
 #include "account-view.h"
 namespace {
@@ -58,7 +59,7 @@ QStringList collectSyncedReposForAccount(const Account& account)
     return repo_ids;
 }
 
-}
+} // namespace
 
 AccountView::AccountView(QWidget *parent)
     : QWidget(parent)
@@ -86,6 +87,11 @@ AccountView::AccountView(QWidget *parent)
             this, SLOT(showAddAccountDialog()));
     connect(mServerAddr, SIGNAL(linkActivated(const QString&)),
             this, SLOT(visitServerInBrowser(const QString&)));
+
+    // Must get the pixmap from QIcon because QIcon would load the 2x version
+    // automatically.
+    mRefreshLabel->setPixmap(QIcon(":/images/toolbar/refresh-new.png").pixmap(20));
+    mRefreshLabel->installEventFilter(this);
 }
 
 void AccountView::showAddAccountDialog()
@@ -345,12 +351,15 @@ bool AccountView::eventFilter(QObject *obj, QEvent *event)
         painter.setRenderHint(QPainter::HighQualityAntialiasing);
 
         // get the device pixel radio from current painter device
-        int scale_factor = painter.device()->devicePixelRatio();
+        double scale_factor = globalDevicePixelRatio();
 
         QPixmap image(mAccountBtn->icon().pixmap(rect.size()).scaled(scale_factor * rect.size()));
-        QRect actualRect(QPoint(0, 0), image.size());
+        QRect actualRect(QPoint(0, 0),
+                         QSize(AvatarService::kAvatarSize * scale_factor,
+                               AvatarService::kAvatarSize * scale_factor));
 
-        QImage masked_image(actualRect.size(), QImage::Format_ARGB32_Premultiplied);
+        QImage masked_image(actualRect.size(),
+                            QImage::Format_ARGB32_Premultiplied);
         masked_image.fill(Qt::transparent);
         QPainter mask_painter;
         mask_painter.begin(&masked_image);
@@ -371,6 +380,18 @@ bool AccountView::eventFilter(QObject *obj, QEvent *event)
         painter.drawImage(QPoint(0,0), masked_image);
         return true;
     }
+    if (obj == mRefreshLabel) {
+        if (event->type() == QEvent::MouseButtonPress) {
+            emit refresh();
+            return true;
+        } else if (event->type() == QEvent::Enter) {
+            mRefreshLabel->setPixmap(QIcon(":/images/toolbar/refresh-orange.png").pixmap(20));
+            return true;
+        } else if (event->type() == QEvent::Leave) {
+            mRefreshLabel->setPixmap(QIcon(":/images/toolbar/refresh-new.png").pixmap(20));
+            return true;
+        }
+    }
     return QObject::eventFilter(obj, event);
 }
 
